@@ -36,14 +36,16 @@ struct AsyncStmtInfo;
  */
 typedef struct RemoteModifyTupleCommon
 {
-	MemoryContext *mem;
+	MemoryContext mem;
 	CommandId cid;
+	Oid relid;
 	Oid identifier_typid;
 	Oid identifier_typmod;
 	TupleDesc identifier_tupdesc;
 	FmgrInfo *identifier_finfo;
 	FmgrInfo *value_finfo;
 	Bitmapset *updatedCols;
+	Bitmapset *identifier_pkcols;
 
 	// struct AsyncStmtInfo *asi;
 	List *asis;
@@ -51,6 +53,10 @@ typedef struct RemoteModifyTupleCommon
 
 	RemoteRWCheckContext *rw_context;
 	List *emit_handles;
+	uint64 processed;
+
+	bool can_recovery_table_migration;
+	int table_migration_recovery_retries;
 } RemoteModifyTupleCommon;
 
 /**
@@ -66,7 +72,8 @@ extern void ExecRemoteDirectDelete(EState *estate, ResultRelInfo *resultRelInfo,
 /**
  * @brief Used by Un-pushdownable DML to insert one tuple in async manner
  */
-extern void ExecRemoteDirectInsert(EState *estate, ResultRelInfo *resultRelInfo, TupleTableSlot *slot);
+extern void ExecRemoteDirectInsert(EState *estate, ResultRelInfo *resultRelInfo, TupleTableSlot *slot,
+				   OnConflictAction onConflict, bool only_insert);
 /**
  * @brief Used by Un-pushdownable delete to construct result relation tuples from child plan slot
  */
@@ -74,7 +81,12 @@ extern void StoreRemoteTupleFromSubPlanSlot(TupleTableSlot *slot,
 				     TupleTableSlot *planslot,
 				     List *positionList);
 
-extern void EndRemoteModifyTupleCommon(ResultRelInfo *resultRelinfo);
+/**
+ * If the length of the sql is greater than throttle, or no longer grows, then emit the generated remote sql.
+ */
+extern void EmitRemoteModifyTupleSQL(ResultRelInfo *resultRelInfo, bool end);
+
+extern void EndRemoteModifyTupleCommon(ResultRelInfo *resultRelinfo, uint64 *processed);
 
 /**
  * struct RemoteUDPushdown 
@@ -144,4 +156,12 @@ extern TupleTableSlot * ExecRemoteUDPushdown(ModifyTableState *node);
  */
 extern void ExecEndRemoteUDPushdown(ModifyTableState *node);
 
+
+/**
+ * @brief 输出被更新列上的约束条件
+ */
+extern bool print_remote_tuple_constraint(RangeTblEntry *rte, Relation relation, StringInfo sql);
+
+extern bool print_remote_tuple_rls(RangeTblEntry *rte, Relation rel, List *withCheckOptions, StringInfo sql);
+
 #endif // !REMOTE_DML_H
