@@ -119,6 +119,7 @@ extern ExprState *execTuplesMatchPrepare(TupleDesc desc,
 					   int numCols,
 					   AttrNumber *keyColIdx,
 					   Oid *eqOperators,
+					   Oid *collations,
 					   PlanState *parent);
 extern void execTuplesHashPrepare(int numCols,
 					  Oid *eqOperators,
@@ -129,6 +130,7 @@ extern TupleHashTable BuildTupleHashTable(PlanState *parent,
 					int numCols, AttrNumber *keyColIdx,
 					Oid *eqfuncoids,
 					FmgrInfo *hashfunctions,
+					Oid *collations,
 					long nbuckets, Size additionalsize,
 					MemoryContext tablecxt,
 					MemoryContext tempcxt, bool use_variable_hash_iv);
@@ -137,6 +139,7 @@ extern TupleHashTable BuildTupleHashTableExt(PlanState *parent,
 					int numCols, AttrNumber *keyColIdx,
 					Oid *eqfuncoids,
 					FmgrInfo *hashfunctions,
+					Oid *collations,
 					long nbuckets, Size additionalsize,
 					MemoryContext metacxt,
 					MemoryContext tablecxt,
@@ -245,6 +248,19 @@ extern void ExecOptimizePlanStateAfterwards(PlanState *planstate);
  * ----------------------------------------------------------------
  */
 #ifndef FRONTEND
+
+static inline void
+PreExecProcNode(PlanState *node)
+{
+	if (node->PreExecProcNode)
+	{
+		if (node->chgParam != NULL)
+			ExecReScan(node);
+
+		node->PreExecProcNode(node);
+	}
+}
+
 static inline TupleTableSlot *
 ExecProcNode(PlanState *node)
 {
@@ -269,6 +285,7 @@ extern ExprState *ExecBuildGroupingEqual(TupleDesc ldesc, TupleDesc rdesc,
 					   int numCols,
 					   AttrNumber *keyColIdx,
 					   Oid *eqfunctions,
+					   Oid *collations,
 					   PlanState *parent);
 extern ProjectionInfo *ExecBuildProjectionInfo(List *targetList,
 						ExprContext *econtext,
