@@ -8,6 +8,13 @@ import json
 import time
 import copy
 from distutils.util import strtobool
+import sys
+
+def my_print(toprint):
+    if sys.version_info.major == 2:
+        sys.stdout.write(toprint + "\n")
+    else:
+        print(toprint)
 
 def connect_mysql(node):
 	try:
@@ -18,7 +25,7 @@ def connect_mysql(node):
 		mysql_conn_params['password'] = node['password']
 		mysql_conn = mysql.connector.connect(**mysql_conn_params)
 	except mysql.connector.errors.InterfaceError as err:
-		print "Unable to connect to {}, error: {}".format(str(mysql_conn_params), str(err))
+		my_print("Unable to connect to {}, error: {}".format(str(mysql_conn_params), str(err)))
 	return mysql_conn
 
 def mysql_version_check(conn, conn_params):
@@ -27,7 +34,7 @@ def mysql_version_check(conn, conn_params):
 	row = csr.fetchone()
 	if row == None or row[0].find("kunlun-storage") < 0:
 		raise Exception("Version mismatch: mysql server {} version is {}, but 8.0.x-kunlun-storage is required.".format(str(conn_params), row[0]))
-	print "Node {} version {} check passes.".format(str(conn_params), row[0])
+	my_print("Node {} version {} check passes.".format(str(conn_params), row[0]))
 	csr.close()
 
 def mysql_node_check_norep(conn_params):
@@ -127,8 +134,8 @@ if __name__ == '__main__':
 	parser = argparse.ArgumentParser(description='test functions in this file')
 	parser.add_argument('--config', help="shard config file path")
 	parser.add_argument('--meta_config', type=str, help="metadata cluster config file path")
-        parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
-        parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
+	parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
+	parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
 
 	args = parser.parse_args()
 
@@ -136,7 +143,7 @@ if __name__ == '__main__':
 	meta_jstr = meta_jsconf.read()
 	meta_jscfg = json.loads(meta_jstr)
 	mysql_conn_params = mysql_shard_check(meta_jscfg, args.meta_ha_mode)
-	print "Meta shard primary node: {}".format(str(mysql_conn_params))
+	my_print("Meta shard primary node: {}".format(str(mysql_conn_params)))
 
 	jsconf = open(args.config)
 	jstr = jsconf.read()
@@ -144,5 +151,5 @@ if __name__ == '__main__':
 
 	for shardcfg in jscfg:
 		mysql_conn_params = mysql_shard_check(shardcfg['shard_nodes'], args.ha_mode)
-		print "Shard {} primary node: {}".format(shardcfg['shard_name'], str(mysql_conn_params))
+		my_print("Shard {} primary node: {}".format(shardcfg['shard_name'], str(mysql_conn_params)))
 
