@@ -42,6 +42,7 @@ CREATE TABLE `commit_log_template_table` (
   `next_txn_cmd` enum('commit','abort') NOT NULL,
   `prepare_ts` timestamp(6) default current_timestamp(6),
   `written_shards` json,
+  `global_version_no` bigint unsigned,
   PRIMARY KEY (`id`,`comp_node_id`,`txn_id`),
   UNIQUE KEY `commit_log_unik` (`comp_node_id`,`txn_id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8
@@ -105,6 +106,8 @@ CREATE TABLE `db_clusters` (
   `memo` text,
   `status` enum('inuse','deleted') DEFAULT 'inuse',
   `ha_mode` enum('no_rep','mgr','rbr') not null,
+  `encrypt_backup` tinyint(1) NOT NULL DEFAULT '0',
+  `backup_encrypt_key` varchar(256) DEFAULT NULL,
   PRIMARY KEY (`id`),
   UNIQUE KEY `name` (`name`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
@@ -154,6 +157,31 @@ CREATE TABLE `comp_nodes` (
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 /*!40101 SET character_set_client = @saved_cs_client */;
 
+DROP TABLE IF EXISTS `proxysql_nodes`;
+/*!40101 SET @saved_cs_client     = @@character_set_client */;
+ SET character_set_client = utf8mb4 ;
+CREATE TABLE `proxysql_nodes` (
+  `id` int unsigned NOT NULL,
+  `name` varchar(64) NOT NULL,
+  `hostaddr` varchar(8192) NOT NULL,
+  `port` smallint unsigned NOT NULL,
+  `db_cluster_id` int unsigned NOT NULL,
+  `when_created` timestamp NULL DEFAULT (now()),
+  `user_name` varchar(64) NOT NULL,
+  `passwd` varchar(16) NOT NULL,
+  `status` enum('creating','inactive','active','deleted','manual_stop') DEFAULT 'creating',
+  `svr_node_id` int unsigned NOT NULL,
+  `cpu_cores` smallint unsigned NOT NULL DEFAULT '0',
+  `max_mem_MB` int unsigned NOT NULL DEFAULT '0',
+  `max_conns` int unsigned NOT NULL DEFAULT '0',
+  `extra_props` text,
+  PRIMARY KEY (`db_cluster_id`,`id`),
+  UNIQUE KEY `cluster_id_name` (`db_cluster_id`,`name`),
+  KEY `svr_node_id` (`svr_node_id`),
+  CONSTRAINT `proxysql_nodes_ibfk_1` FOREIGN KEY (`db_cluster_id`) REFERENCES `db_clusters` (`id`),
+  CONSTRAINT `proxysql_nodes_ibfk_2` FOREIGN KEY (`svr_node_id`) REFERENCES `server_nodes` (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+/*!40101 SET character_set_client = @saved_cs_client */;
 
 --
 -- Table structure for table `ddl_ops_log_template_table`
@@ -170,7 +198,7 @@ CREATE TABLE `ddl_ops_log_template_table` (
   `user_name` varchar(64) NOT NULL,
   `role_name` varchar(64) NOT NULL,
   `search_path` text NOT NULL,
-  `optype` enum('create','drop','rename','alter','replace', 'remap_shardid', 'others') NOT NULL,
+  `optype` enum('create','drop','rename','alter','replace', 'remap_shardid', 'add_shard', 'add_node', 'delete_shard', 'delete_node', 'add_computer', 'others') NOT NULL,
   `objtype` enum('db','index','matview','partition','schema','seq','table','func','role_or_group','proc','stats','user','view', 'others') NOT NULL,
   `when_logged` timestamp(6) NULL DEFAULT current_timestamp(6),
   `sql_src` text NOT NULL,
@@ -342,6 +370,8 @@ CREATE TABLE `shard_nodes` (
   cpu_limit_mode enum('share','quota') DEFAULT 'share',
   initial_storage_GB int unsigned NOT NULL default 0,
   max_storage_GB int unsigned NOT NULL default 0,
+  data_storage_MB int unsigned NOT NULL DEFAULT '0',
+  log_storage_MB int unsigned NOT NULL DEFAULT '0',
   innodb_buffer_pool_MB int unsigned NOT NULL default 0,
   rocksdb_buffer_pool_MB int unsigned NOT NULL default 0,
 
@@ -546,7 +576,7 @@ create table table_move_jobs (
 	tab_file_format enum('logical', 'physical', 'dyn_clone') not null,
 	when_started timestamp(6) not null default current_timestamp(6),
 	when_ended timestamp(6) NULL default null,
-	status varchar(128) not null default 'not_started', -- ('not_started', 'dumped', 'transmitted', 'loaded', 'caught_up', 'renamed', 'rerouted', 'done', 'failed'),
+	status varchar(128) not null default 'not_started', -- ('not_started', 'done', 'failed'),
 	stage varchar(128) not null default 'not_started', -- ('not_started', 'dumped', 'transmitted', 'loaded', 'caught_up', 'renamed', 'rerouted', 'done', 'failed'),
   binlog_gtid_before_reroute varchar(256) NULL default null,
   binlog_idx_before_reroute varchar(256) NULL default null,
@@ -590,6 +620,7 @@ CREATE TABLE `cluster_mgr_nodes` (
 	`id` int unsigned NOT NULL AUTO_INCREMENT,
 	`hostaddr` varchar(8192) character set latin1 NOT NULL,
 	`port` int unsigned DEFAULT NULL,
+	`raft_port` int unsigned DEFAULT NULL,
 	`prometheus_port` int unsigned DEFAULT NULL,
 	`member_state` enum('source','replica') DEFAULT 'replica',
 	PRIMARY KEY (`id`)
@@ -729,4 +760,34 @@ CREATE TABLE `user_consumption` (
   PRIMARY KEY (`id`),
   KEY `id_name` (`cluster_id`,`user_name`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
+
+DROP TABLE IF EXISTS `cluster_rcr_infos`;
+create table `cluster_rcr_infos` (
+	`id` int unsigned NOT NULL AUTO_INCREMENT,
+	`master_rcr_meta` varchar(255) default '',
+	`master_cluster_id` int unsigned default '0',
+	`slave_rcr_meta` varchar(255) default '',
+	`slave_cluster_id` int unsigned default '0',
+	`shard_maps` text,
+	`status` enum('creating','running','deleted','manual_stop','manual_rcrsw') DEFAULT 'creating',
+	`conf_delay_sync` int NOT NULL DEFAULT '0',
+	`sync_host_delay` int NOT NULL DEFAULT '0',
+	`replica_delay` int NOT NULL DEFAULT '0',
+	`when_created` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
+	primary key(`id`)
+);
+
+DROP TABLE IF EXISTS `cluster_rcr_meta_sync`;
+create table `cluster_rcr_meta_sync` (
+	`id` int unsigned NOT NULL AUTO_INCREMENT,
+	`rcr_infos_id` int unsigned default '0',
+	`dump_host` varchar(32) default '',
+	`meta_sync_state` enum('creating','dump','sync','disconnect','deleted') default 'creating',
+	`sync_binlog_file` varchar(255) default '',
+	`sync_binlog_pos` bigint NOT NULL DEFAULT '0',
+	`sync_gtid` text,
+	`alldump_pos` int unsigned DEFAULT '0',
+	`update_ts` varchar(16) default '',
+	primary key(`id`)
+);
 -- Dump completed on 2020-01-04 11:14:45
